summaryrefslogtreecommitdiff
path: root/src/game/bg_misc.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/bg_misc.c')
-rw-r--r--src/game/bg_misc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/game/bg_misc.c b/src/game/bg_misc.c
index 2641305..2b4fa29 100644
--- a/src/game/bg_misc.c
+++ b/src/game/bg_misc.c
@@ -4828,8 +4828,8 @@ void BG_PlayerStateToEntityState( playerState_t *ps, entityState_t *s, qboolean
}
}
- //TA: use powerups field to store team/class info:
- s->powerups = ps->stats[ STAT_PTEAM ] | ( ps->stats[ STAT_PCLASS ] << 8 );
+ // use misc field to store team/class info:
+ s->misc = ps->stats[ STAT_PTEAM ] | ( ps->stats[ STAT_PCLASS ] << 8 );
//TA: have to get the surfNormal thru somehow...
VectorCopy( ps->grapplePoint, s->angles2 );
@@ -4940,8 +4940,8 @@ void BG_PlayerStateToEntityStateExtraPolate( playerState_t *ps, entityState_t *s
}
}
- //TA: use powerups field to store team/class info:
- s->powerups = ps->stats[ STAT_PTEAM ] | ( ps->stats[ STAT_PCLASS ] << 8 );
+ // use misc field to store team/class info:
+ s->misc = ps->stats[ STAT_PTEAM ] | ( ps->stats[ STAT_PCLASS ] << 8 );
//TA: have to get the surfNormal thru somehow...
VectorCopy( ps->grapplePoint, s->angles2 );